package app;


import javax.jcr.Repository;
import javax.jcr.RepositoryException;
import javax.jcr.Session;
import javax.naming.InitialContext;
import javax.naming.NamingException;

import org.apache.jackrabbit.commons.JcrUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


public class App {

	private static final Logger logger = LoggerFactory.getLogger(App.class);

	/**
	 * Returns the repository obtained from explicit JNDI lookup by the jcr/Repository jndi name.
	 * 
	 * @return repository
	 * @throws NamingException
	 *             the naming exception
	 */
	public static void getRepositoryUsingExplicitJNDI() {
		getRepositoryUsingExplicitJNDI("jcr/Repository");
	}

	/**
	 * Returns the repository obtained from explicit JNDI lookup.
	 * 
	 * @param jndiName
	 *            o(a) jndi name
	 * @return repository
	 */
	public static void getRepositoryUsingExplicitJNDI(String jndiName) {
		try {
			InitialContext ic;
			try {
				ic = new InitialContext();
				Repository rep;
				try {
					rep = (Repository) ic.lookup(jndiName);
					Session session = rep.login();
					logger.debug("Workspace: " + session.getWorkspace().getName() + "\n");
				} catch (NamingException e) {
					logger.error("Failed to get the repository.", e);

				}
			} catch (NamingException e) {
				logger.error("Failed to initiate the context.", e);
			}

		} catch (RepositoryException e) {
			logger.error("Failed access the primefaces.", e);
		}
	}

	/**
	 * Returns the repository obtained from JcrUtils uri utility by the uri jndi:jcr/Repository.
	 * 
	 * @return repository
	 * @throws NamingException
	 *             the naming exception
	 */
	public static void getRepositoryUsingJCRUtils() {
		getRepositoryUsingJCRUtils("jcr/Repository");
	}

	/**
	 * Returns the repository obtained from JcrUtils uri utility.
	 * 
	 * @return repository
	 * @throws NamingException
	 *             the naming exception
	 */
	public static void getRepositoryUsingJCRUtils(String jndiName) {
		try {
			Repository rep = JcrUtils.getRepository("jndi:" + jndiName);
			Session session = rep.login();
			logger.debug("Workspace: " + session.getWorkspace().getName());

		} catch (RepositoryException e) {
			logger.error("Failed access the repository.", e);
		}
	}

}
